import './types/embed/v3/events/incoming.js';
import './types/embed/v3/events/outgoing.js';
import './types/embed/v3/events/EmbeddedCheckoutV3IFrameEmitter.js';
import { CrossmintEvents } from './types/events/public/events.js';
import { CrossmintInternalEvents, IncomingInternalEvents, OutgoingInternalEvents } from './types/events/internal/events.js';
import { EVMBlockchainIncludingTestnet, UIConfig, BlockchainIncludingTestnet, PayerSupportedBlockchains, Blockchain } from '@crossmint/common-sdk-base';
import { EmptyObject, CaseInsensitive } from './types/system.js';
import { updatableFiatParams, updatableCryptoParams } from './consts/embed.js';
import { Transaction } from '@ethersproject/transactions';
import { Transaction as Transaction$1 } from '@solana/web3.js';
import { CryptoCurrency } from './types/CryptoCurrency.js';

interface CrossmintEventMap {
    [CrossmintEvents.PAYMENT_PREPARATION_SUCCEEDED]: EmptyObject;
    [CrossmintEvents.QUOTE_STATUS_CHANGED]: InitialQuotePayload;
    [CrossmintEvents.QUOTE_STATUS_INVALIDATED]: EmptyObject;
    [CrossmintEvents.PAYMENT_PROCESS_STARTED]: InitialQuotePayload;
    [CrossmintEvents.PAYMENT_PREPARATION_FAILED]: CrossmintEventErrorPayload;
    [CrossmintEvents.PAYMENT_PROCESS_SUCCEEDED]: PaymentCompletedPayload;
    [CrossmintEvents.PAYMENT_PROCESS_CANCELED]: EmptyObject;
    [CrossmintEvents.PAYMENT_PROCESS_REJECTED]: PaymentRejectedPayload;
    [CrossmintEvents.ORDER_PROCESS_STARTED]: EmptyObject;
    [CrossmintEvents.TRANSACTION_FULFILLMENT_SUCCEEDED]: TransactionFulfillmentSucceededPayload;
    [CrossmintEvents.TRANSACTION_FULFILLMENT_FAILED]: TransactionFulfillmentFailedPayload;
    [CrossmintEvents.ORDER_PROCESS_FINISHED]: OrderProcessFinishedPayload;
    [CrossmintEvents.RECIPIENT_WALLET_CHANGED]: RecipientWalletChangedPayload;
    [CrossmintEvents.RECIPIENT_EMAIL_CHANGED]: RecipientEmailChangedPayload;
}
interface InitialQuotePayload {
    totalPrice: FiatPrice;
    lineItems: LineItem[];
}
interface LineItem {
    price: FiatPrice;
    gasFee?: FiatPrice;
    metadata: LineItemMetadata;
    quantity: number;
}
interface LineItemMetadata {
    imageUrl?: string;
    description?: string;
    title?: string;
    collection?: string;
}
interface CrossmintEventErrorPayload {
    error: CrossmintEventError;
}
interface CrossmintEventError {
    message: string;
    code: string;
}
interface PaymentCompletedPayload {
    orderIdentifier: string;
}
interface PaymentRejectedPayload extends CrossmintEventErrorPayload {
    orderIdentifier: string;
    paymentMethodType: PaymentMethodType;
}
declare const PaymentMethodType: {
    readonly CREDIT_CARD: "credit-card";
    readonly GOOGLE_PAY: "google-pay";
    readonly APPLE_PAY: "apple-pay";
};
type PaymentMethodType = (typeof PaymentMethodType)[keyof typeof PaymentMethodType];
type TransactionFulfillmentSucceededPayload = {
    transactionIdentifier: string;
    price: FiatPrice;
    txId: string;
} & (EVMTransaction | SolanaTransaction$1);
interface EVMTransaction {
    contractAddress: string;
    tokenIds: string[];
}
interface SolanaTransaction$1 {
    mintHash: string;
}
interface TransactionFulfillmentFailedPayload {
    transactionIdentifier: string;
    price: FiatPrice;
    error: CrossmintEventError;
}
interface OrderProcessFinishedPayload {
    successfulTransactionIdentifiers: string[];
    failedTransactionIdentifiers: string[];
    verification: {
        required: false;
    } | {
        required: true;
        url: string;
    };
    totalPrice: FiatPrice;
    paymentMethodType: PaymentMethodType;
}
interface RecipientWalletChangedPayload {
    wallet: string;
}
interface RecipientEmailChangedPayload {
    email: string;
}

type CrossmintEvent = {
    [K in CrossmintEvents]: {
        type: K;
        payload: CrossmintEventMap[K];
    };
}[CrossmintEvents];

type CryptoEmbeddedCheckoutPropsBase<PM extends keyof CryptoPaymentMethodSignerMap = keyof CryptoPaymentMethodSignerMap> = CommonEmbeddedCheckoutProps<PM> & {
    paymentMethod: PM;
    signer?: CryptoPaymentMethodSignerMap[PM];
};
type CryptoEmbeddedCheckoutPropsWithSignerBase<PM extends keyof CryptoPaymentMethodSignerMap = keyof CryptoPaymentMethodSignerMap> = CryptoEmbeddedCheckoutPropsBase<PM> & {
    signer: CryptoPaymentMethodSignerMap[PM];
};
type CryptoEmbeddedCheckoutPropsWithSigner = {
    [PM in keyof CryptoPaymentMethodSignerMap]: CryptoEmbeddedCheckoutPropsWithSignerBase<PM>;
}[keyof CryptoPaymentMethodSignerMap];
type CryptoEmbeddedCheckoutProps = {
    [PM in keyof CryptoPaymentMethodSignerMap]: CryptoEmbeddedCheckoutPropsBase<PM>;
}[keyof CryptoPaymentMethodSignerMap] | CryptoEmbeddedCheckoutPropsWithSigner;
type CryptoPaymentMethodSignerMap = {
    [CryptoPaymentMethod.ETH]: ETHEmbeddedCheckoutSigner;
    [CryptoPaymentMethod.SOL]: SOLEmbeddedCheckoutSigner;
};
type CommonEmbeddedCheckoutSignerProps = {
    address: string;
};
type EthersTransaction = Transaction;
type SolanaTransaction = Transaction$1;
type ETHEmbeddedCheckoutSigner = CommonEmbeddedCheckoutSignerProps & {
    signAndSendTransaction: (transaction: EthersTransaction) => Promise<string>;
    chain?: EVMBlockchainIncludingTestnet;
    supportedChains?: EVMBlockchainIncludingTestnet[];
    handleChainSwitch?: (network: EVMBlockchainIncludingTestnet) => Promise<void>;
};
type SOLEmbeddedCheckoutSigner = CommonEmbeddedCheckoutSignerProps & {
    signAndSendTransaction: (transaction: SolanaTransaction) => Promise<string>;
};

type FiatEmbeddedCheckoutProps = CommonEmbeddedCheckoutProps<"fiat"> & {
    cardWalletPaymentMethods?: CardWalletPaymentMethod | CardWalletPaymentMethod[] | "none";
    emailInputOptions?: EmailInputOptions;
    experimental?: EmbeddedCheckoutExperimentalOptions;
};
type CardWalletPaymentMethod = "apple-pay" | "google-pay";
type EmailInputOptions = {
    show: true;
    useStripeLink?: boolean;
} | {
    show: false;
};
type EmbeddedCheckoutExperimentalOptions = {
    useCardWalletEmail?: boolean;
};

type CryptoEmbeddedCheckoutPropsJSONStringified<PM extends keyof CryptoPaymentMethodSignerMap = keyof CryptoPaymentMethodSignerMap> = CommonEmbeddedCheckoutPropsJSONStringified<PM> & {
    paymentMethod: PM;
    signer?: string;
};
type CryptoEmbeddedCheckoutPropsJSONParsed<PM extends keyof CryptoPaymentMethodSignerMap = keyof CryptoPaymentMethodSignerMap> = CommonEmbeddedCheckoutPropsJSONStringified<PM> & {
    paymentMethod: PM;
    signer?: CommonEmbeddedCheckoutSignerProps;
};

type FiatEmbeddedCheckoutPropsJSONStringified = CommonEmbeddedCheckoutPropsJSONStringified<"fiat"> & {
    cardWalletPaymentMethods?: string;
    emailInputOptions?: string;
    experimental?: string;
};
type FiatEmbeddedCheckoutPropsJSONParsed = CommonEmbeddedCheckoutPropsJSONParsed<"fiat"> & {
    cardWalletPaymentMethods?: CardWalletPaymentMethod | CardWalletPaymentMethod[] | "none";
    emailInputOptions?: EmailInputOptions;
    experimental?: EmbeddedCheckoutExperimentalOptions;
};

type CommonEmbeddedCheckoutPropsJSONStringified<PM extends PaymentMethod = PaymentMethod> = {
    paymentMethod?: PM;
    mintConfig?: string;
    currency?: CaseInsensitive<Currency>;
    locale?: Locale;
    uiConfig?: string;
    whPassThroughArgs?: string;
    projectId?: string;
    recipient?: string;
} & CollectionOrClientId;
type CommonEmbeddedCheckoutPropsJSONParsed<PM extends PaymentMethod = PaymentMethod> = {
    paymentMethod?: PM;
    mintConfig?: MintConfigs;
    currency?: CaseInsensitive<Currency>;
    locale?: Locale;
    uiConfig?: UIConfig;
    whPassThroughArgs?: any;
    projectId?: string;
    recipient?: Recipient;
} & CollectionOrClientId;
type CrossmintEmbeddedCheckoutPropsJSONStringified = FiatEmbeddedCheckoutPropsJSONStringified | CryptoEmbeddedCheckoutPropsJSONStringified;
type CrossmintEmbeddedCheckoutPropsJSONParsed = FiatEmbeddedCheckoutPropsJSONParsed | CryptoEmbeddedCheckoutPropsJSONParsed;

type UpdatableFiatParams = Pick<FiatEmbeddedCheckoutPropsJSONParsed, (typeof updatableFiatParams)[number]>;
type UpdatableCryptoParams = Pick<CryptoEmbeddedCheckoutPropsJSONParsed, (typeof updatableCryptoParams)[number]>;
type UpdatableEmbeddedCheckoutParams = UpdatableFiatParams | UpdatableCryptoParams;

interface CrossmintEmbeddedCheckoutV3CommonProps {
    appearance?: EmbeddedCheckoutV3Appearance;
    payment: EmbeddedCheckoutV3Payment;
}
interface CrossmintEmbeddedCheckoutV3ExistingOrderProps extends CrossmintEmbeddedCheckoutV3CommonProps {
    orderId: string;
    lineItems?: never;
    recipient?: never;
    locale?: never;
}
interface CrossmintEmbeddedCheckoutV3NewOrderProps extends CrossmintEmbeddedCheckoutV3CommonProps {
    orderId?: never;
    lineItems: EmbeddedCheckoutV3LineItem | EmbeddedCheckoutV3LineItem[];
    recipient?: EmbeddedCheckoutV3Recipient;
    locale?: Locale;
}
type CrossmintEmbeddedCheckoutV3Props = CrossmintEmbeddedCheckoutV3ExistingOrderProps | CrossmintEmbeddedCheckoutV3NewOrderProps;
type EmbeddedCheckoutV3Recipient = EmbeddedCheckoutV3EmailRecipient | EmbeddedCheckoutV3WalletAddressRecipient;
type EmbeddedCheckoutV3PhysicalAddress = {
    name: string;
    line1: string;
    line2?: string;
    city: string;
    state: string;
    postalCode: string;
    country: "US";
};
type EmbeddedCheckoutV3EmailRecipient = {
    email: string;
    walletAddress?: never;
    physicalAddress?: EmbeddedCheckoutV3PhysicalAddress;
};
type EmbeddedCheckoutV3WalletAddressRecipient = {
    walletAddress: string;
    email?: never;
    physicalAddress?: EmbeddedCheckoutV3PhysicalAddress;
};
type EmbeddedCheckoutV3LineItem = {
    collectionLocator: string;
    callData?: Record<string, any>;
} | {
    tokenLocator: string;
    callData?: Record<string, any>;
    executionParameters?: never;
} | {
    tokenLocator: string;
    callData?: never;
    executionParameters?: Record<string, any>;
} | {
    productLocator: string;
};
type EmbeddedCheckoutV3Appearance = {
    fonts?: Array<{
        cssSrc: string;
    }>;
    variables?: EmbeddedCheckoutV3AppearanceVariables;
    rules?: EmbeddedCheckoutV3AppearanceRules;
};
type EmbeddedCheckoutV3AppearanceVariables = {
    fontFamily?: string;
    spacingUnit?: string;
    fontSizeUnit?: string;
    borderRadius?: string;
    colors?: {
        borderPrimary?: string;
        backgroundPrimary?: string;
        textPrimary?: string;
        textSecondary?: string;
        danger?: string;
        warning?: string;
        accent?: string;
    };
};
type EmbeddedCheckoutV3AppearanceRules = {
    DestinationInput?: {
        display?: "hidden";
    };
    ReceiptEmailInput?: {
        display?: "hidden";
    };
    Label?: {
        font?: {
            family?: string;
            size?: string;
            weight?: string;
        };
        colors?: {
            text?: string;
        };
    };
    Input?: {
        borderRadius?: string;
        font?: {
            family?: string;
            size?: string;
            weight?: string;
        };
        colors?: {
            text?: string;
            background?: string;
            border?: string;
            boxShadow?: string;
            placeholder?: string;
        };
        hover?: {
            colors?: {
                text?: string;
                background?: string;
                border?: string;
                boxShadow?: string;
            };
        };
        focus?: {
            colors?: {
                background?: string;
                border?: string;
                boxShadow?: string;
            };
        };
    };
    Tab?: {
        borderRadius?: string;
        font?: {
            family?: string;
            size?: string;
            weight?: string;
        };
        colors?: {
            text?: string;
            background?: string;
            border?: string;
            boxShadow?: string;
        };
        hover?: {
            colors?: {
                text?: string;
                background?: string;
                border?: string;
                boxShadow?: string;
            };
        };
        selected?: {
            colors?: {
                text?: string;
                background?: string;
                border?: string;
                boxShadow?: string;
            };
        };
    };
    PrimaryButton?: {
        borderRadius?: string;
        font?: {
            family?: string;
            size?: string;
            weight?: string;
        };
        colors?: {
            text?: string;
            background?: string;
        };
        hover?: {
            colors?: {
                text?: string;
                background?: string;
            };
        };
        disabled?: {
            colors?: {
                text?: string;
                background?: string;
            };
        };
    };
};
type EmbeddedCheckoutV3Payment = {
    receiptEmail?: string;
    fiat: EmbeddedCheckoutV3FiatPayment;
    crypto: EmbeddedCheckoutV3CryptoPayment;
    defaultMethod?: "fiat" | "crypto";
};
type EmbeddedCheckoutV3FiatPayment = {
    enabled: boolean;
    defaultCurrency?: Currency;
    allowedMethods?: {
        card?: boolean;
        applePay?: boolean;
        googlePay?: boolean;
    };
};
type EmbeddedCheckoutV3CryptoPayment = {
    enabled: boolean;
    defaultChain?: BlockchainIncludingTestnet;
    defaultCurrency?: CryptoCurrency;
    payer?: EmbeddedCheckoutPayer;
};
type TransactionResponse = {
    success: true;
    txId: string;
} | {
    success: false;
    errorMessage: string;
};
type EmbeddedCheckoutPayer = {
    address: string;
    initialChain: PayerSupportedBlockchains;
    supportedChains?: PayerSupportedBlockchains[];
    handleSignAndSendTransaction(serializedTransaction: string): Promise<TransactionResponse>;
    handleChainSwitch(chain: PayerSupportedBlockchains): Promise<void>;
};

type CommonEmbeddedCheckoutProps<PM extends PaymentMethod = PaymentMethod> = {
    paymentMethod?: PM;
    mintConfig?: MintConfigs;
    currency?: CaseInsensitive<Currency>;
    locale?: Locale;
    environment?: string;
    uiConfig?: UIConfig;
    whPassThroughArgs?: any;
    projectId?: string;
    recipient?: Recipient;
    onEvent?(event: CrossmintEvent): any;
    debug?: boolean;
} & CollectionOrClientId;
type CrossmintEmbeddedCheckoutProps = FiatEmbeddedCheckoutProps | CryptoEmbeddedCheckoutProps;

interface IncomingInternalEventMap {
    [CrossmintInternalEvents.UI_HEIGHT_CHANGED]: {
        height: number;
    };
    [CrossmintInternalEvents.CRYPTO_PAYMENT_INCOMING_TRANSACTION]: {
        serializedTransaction: string;
    };
    [CrossmintInternalEvents.CRYPTO_CHAIN_SWITCH]: {
        chain: Blockchain;
    };
}
interface OutgoingInternalEventMap {
    [CrossmintInternalEvents.PARAMS_UPDATE]: UpdatableEmbeddedCheckoutParams;
    [CrossmintInternalEvents.CRYPTO_PAYMENT_USER_ACCEPTED]: {
        txId: string;
    };
    [CrossmintInternalEvents.CRYPTO_PAYMENT_USER_REJECTED]: EmptyObject;
}
type CrossmintInternalEventMap = IncomingInternalEventMap & OutgoingInternalEventMap;

type IncomingInternalEvent = {
    [K in IncomingInternalEvents]: {
        type: K;
        payload: CrossmintInternalEventMap[K];
    };
}[IncomingInternalEvents];
type OutgoingInternalEvent = {
    [K in OutgoingInternalEvents]: {
        type: K;
        payload: CrossmintInternalEventMap[K];
    };
}[OutgoingInternalEvents];
type CrossmintInternalEvent = IncomingInternalEvent | OutgoingInternalEvent;

interface CrossmintHostedCheckoutV3Props {
    recipient?: EmbeddedCheckoutV3Recipient;
    locale?: Locale;
    lineItems: EmbeddedCheckoutV3LineItem | EmbeddedCheckoutV3LineItem[];
    payment: HostedCheckoutV3Payment;
    appearance?: CrossmintHostedCheckoutV3Appearance;
}
type HostedCheckoutV3Payment = {
    receiptEmail?: string;
    fiat: HostedCheckoutV3FiatPayment;
    crypto: HostedCheckoutV3CryptoPayment;
    defaultMethod?: "fiat" | "crypto";
};
type HostedCheckoutV3FiatPayment = {
    enabled: boolean;
    defaultCurrency?: Currency;
};
type HostedCheckoutV3CryptoPayment = {
    enabled: boolean;
    defaultChain?: BlockchainIncludingTestnet;
    defaultCurrency?: CryptoCurrency;
};
interface CrossmintHostedCheckoutV3Appearance {
    theme?: {
        checkout?: CrossmintHostedCheckoutV3Theme;
        button?: CrossmintHostedCheckoutV3ButtonTheme;
    };
    variables?: CrossmintHostedCheckoutV3AppearanceVariables;
    overlay?: CrossmintHostedCheckoutV3OverlayOptions;
    display?: "popup" | "new-tab" | "same-tab";
    rules?: HostedCheckoutV3AppearanceRules;
}
type HostedCheckoutV3AppearanceRules = {
    DestinationInput?: {
        display?: "hidden";
    };
    ReceiptEmailInput?: {
        display?: "hidden";
    };
};
type CrossmintHostedCheckoutV3Theme = "light" | "dark";
type CrossmintHostedCheckoutV3ButtonTheme = "light" | "dark" | "crossmint";
interface CrossmintHostedCheckoutV3AppearanceVariables {
    colors?: {
        accent?: string;
    };
}
type CrossmintHostedCheckoutV3OverlayOptions = {
    enabled: boolean;
};

type MintConfig = Record<string, any> | Record<string, any>[];
type MintConfigs = MintConfig | MintConfig[];
type CrossmintPayButtonTheme = "light" | "dark";
type CollectionOrClientId = {
    clientId: string;
} | {
    collectionId: string;
};
type BaseButtonProps = {
    projectId?: string;
    className?: string;
    disabled?: boolean;
    tabIndex?: number;
    auctionId?: string;
    theme?: CrossmintPayButtonTheme;
    platformId?: string;
    mintConfig?: MintConfigs;
    environment?: string;
    locale?: Locale;
    currency?: CaseInsensitive<Currency>;
} & CollectionOrClientId;
type CrossmintPayButtonProps = BaseButtonProps & {
    mintTo?: string;
    emailTo?: string;
    listingId?: string;
    showOverlay?: boolean;
    dismissOverlayOnClick?: boolean;
    whPassThroughArgs?: any;
    paymentMethod?: PaymentMethod;
    preferredSigninMethod?: SigninMethods;
    prepay?: boolean;
    successCallbackURL?: string;
    failureCallbackURL?: string;
    loginEmail?: string;
    getButtonText?: (connecting: boolean, paymentMethod: PaymentMethod) => string;
    checkoutProps?: CheckoutProps;
};
type CheckoutProps = {
    experimental?: boolean;
    display?: "same-tab" | "new-tab" | "popup";
    delivery?: "custodial" | "non-custodial" | "all";
    paymentMethods?: PaymentMethod[];
};
type SigninMethods = "metamask" | "solana";

declare enum clientNames {
    reactUi = "client-sdk-react-ui",
    vanillaUi = "client-sdk-vanilla-ui"
}
declare const BaseUrls: {
    readonly prod: "https://www.crossmint.com";
    readonly staging: "https://staging.crossmint.com";
    readonly dev: "http://localhost:3001";
};
type BaseUrls = (typeof BaseUrls)[keyof typeof BaseUrls];
declare const CryptoPaymentMethod: {
    readonly ETH: "ETH";
    readonly SOL: "SOL";
};
type CryptoPaymentMethod = (typeof CryptoPaymentMethod)[keyof typeof CryptoPaymentMethod];
declare const PaymentMethod: {
    readonly ETH: "ETH";
    readonly SOL: "SOL";
    readonly FIAT: "fiat";
};
type PaymentMethod = (typeof PaymentMethod)[keyof typeof PaymentMethod];
declare const paymentMethodIsEth: (paymentMethod?: PaymentMethod) => paymentMethod is "ETH";
declare const paymentMethodIsSol: (paymentMethod?: PaymentMethod) => paymentMethod is "SOL";
type Locale = "en-US" | "es-ES" | "fr-FR" | "it-IT" | "ja-JP" | "ko-KR" | "pt-PT" | "zh-CN" | "zh-TW" | "de-DE" | "ru-RU" | "tr-TR" | "uk-UA" | "th-TH" | "vi-VN" | "Klingon";
type Currency = "usd" | "eur" | "gbp" | "aud" | "sgd" | "hkd" | "krw" | "inr" | "vnd" | "jpy";
interface FiatPrice {
    amount: string;
    currency: Currency;
}
type Recipient = {
    email?: string;
    wallet?: string;
};

export { type CommonEmbeddedCheckoutPropsJSONParsed as $, type CrossmintHostedCheckoutV3ButtonTheme as A, BaseUrls as B, CryptoPaymentMethod as C, type CrossmintHostedCheckoutV3AppearanceVariables as D, type CrossmintHostedCheckoutV3OverlayOptions as E, type FiatPrice as F, type CommonEmbeddedCheckoutProps as G, type HostedCheckoutV3Payment as H, type InitialQuotePayload as I, type CrossmintEmbeddedCheckoutProps as J, type CryptoEmbeddedCheckoutPropsWithSigner as K, type Locale as L, type MintConfig as M, type CryptoEmbeddedCheckoutProps as N, type OutgoingInternalEvent as O, PaymentMethod as P, type CryptoPaymentMethodSignerMap as Q, type Recipient as R, type SigninMethods as S, type CommonEmbeddedCheckoutSignerProps as T, type ETHEmbeddedCheckoutSigner as U, type SOLEmbeddedCheckoutSigner as V, type FiatEmbeddedCheckoutProps as W, type CardWalletPaymentMethod as X, type EmailInputOptions as Y, type EmbeddedCheckoutExperimentalOptions as Z, type CommonEmbeddedCheckoutPropsJSONStringified as _, paymentMethodIsSol as a, type CrossmintEmbeddedCheckoutPropsJSONStringified as a0, type CrossmintEmbeddedCheckoutPropsJSONParsed as a1, type UpdatableFiatParams as a2, type UpdatableCryptoParams as a3, type UpdatableEmbeddedCheckoutParams as a4, type CrossmintEmbeddedCheckoutV3ExistingOrderProps as a5, type CrossmintEmbeddedCheckoutV3NewOrderProps as a6, type CrossmintEmbeddedCheckoutV3Props as a7, type EmbeddedCheckoutV3Recipient as a8, type EmbeddedCheckoutV3PhysicalAddress as a9, type EmbeddedCheckoutV3EmailRecipient as aa, type EmbeddedCheckoutV3WalletAddressRecipient as ab, type EmbeddedCheckoutV3LineItem as ac, type EmbeddedCheckoutV3Appearance as ad, type EmbeddedCheckoutV3AppearanceVariables as ae, type EmbeddedCheckoutV3AppearanceRules as af, type EmbeddedCheckoutV3Payment as ag, type EmbeddedCheckoutV3FiatPayment as ah, type EmbeddedCheckoutV3CryptoPayment as ai, type TransactionResponse as aj, type EmbeddedCheckoutPayer as ak, type CryptoEmbeddedCheckoutPropsJSONStringified as al, type CryptoEmbeddedCheckoutPropsJSONParsed as am, type FiatEmbeddedCheckoutPropsJSONStringified as an, type FiatEmbeddedCheckoutPropsJSONParsed as ao, type Currency as b, clientNames as c, type CrossmintEvent as d, type CrossmintEventMap as e, type LineItem as f, type LineItemMetadata as g, type CrossmintEventErrorPayload as h, type CrossmintEventError as i, PaymentMethodType as j, type IncomingInternalEvent as k, type CrossmintInternalEvent as l, type CrossmintInternalEventMap as m, type MintConfigs as n, type CrossmintPayButtonTheme as o, paymentMethodIsEth as p, type CollectionOrClientId as q, type BaseButtonProps as r, type CrossmintPayButtonProps as s, type CheckoutProps as t, type CrossmintHostedCheckoutV3Props as u, type HostedCheckoutV3FiatPayment as v, type HostedCheckoutV3CryptoPayment as w, type CrossmintHostedCheckoutV3Appearance as x, type HostedCheckoutV3AppearanceRules as y, type CrossmintHostedCheckoutV3Theme as z };
